==> haskell-bloomfilter-2.0.1.2-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bloomfilter.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 bloomfilter
version:              2.0.1.2
visibility:           public
id:                   bloomfilter-2.0.1.2-9fFZI0q7zFH8lm9vcFqcNN
key:                  bloomfilter-2.0.1.2-9fFZI0q7zFH8lm9vcFqcNN
license:              BSD-3-Clause
maintainer:           Joey Hess <id@joeyh.name>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
stability:            provisional
homepage:             https://github.com/haskell-pkg-janitors/bloomfilter
synopsis:             Pure and impure Bloom Filter implementations.
description:          Pure and impure Bloom Filter implementations.
category:             Data
abi:                  8282fd4cd7b8baf617174f05df338325
exposed:              True
exposed-modules:
    Data.BloomFilter Data.BloomFilter.Easy Data.BloomFilter.Hash
    Data.BloomFilter.Mutable

hidden-modules:
    Data.BloomFilter.Array Data.BloomFilter.Mutable.Internal
    Data.BloomFilter.Util

import-dirs:          /usr/lib/ghc-9.0.2/site-local/bloomfilter-2.0.1.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/bloomfilter-2.0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bloomfilter
hs-libraries:         HSbloomfilter-2.0.1.2-9fFZI0q7zFH8lm9vcFqcNN
include-dirs:         /usr/lib/ghc-9.0.2/site-local/bloomfilter-2.0.1.2/include
includes:             lookup3.h
depends:
    array-0.5.4.0 base-4.15.1.0 bytestring-0.10.12.1 deepseq-1.4.5.0

haddock-interfaces:   /usr/share/doc/haskell-bloomfilter/html/bloomfilter.haddock
haddock-html:         /usr/share/doc/haskell-bloomfilter/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bloomfilter-2.0.1.2-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bloomfilter.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 bloomfilter
version:              2.0.1.2
visibility:           public
id:                   bloomfilter-2.0.1.2-JJba1usFi2T49LbYQ8hqND
key:                  bloomfilter-2.0.1.2-JJba1usFi2T49LbYQ8hqND
license:              BSD-3-Clause
maintainer:           Joey Hess <id@joeyh.name>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
stability:            provisional
homepage:             https://github.com/haskell-pkg-janitors/bloomfilter
synopsis:             Pure and impure Bloom Filter implementations.
description:          Pure and impure Bloom Filter implementations.
category:             Data
abi:                  78cb8f5c46be69f47357fc74ff55cab8
exposed:              True
exposed-modules:
    Data.BloomFilter Data.BloomFilter.Easy Data.BloomFilter.Hash
    Data.BloomFilter.Mutable

hidden-modules:
    Data.BloomFilter.Array Data.BloomFilter.Mutable.Internal
    Data.BloomFilter.Util

import-dirs:          /usr/lib/ghc-9.2.8/site-local/bloomfilter-2.0.1.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/bloomfilter-2.0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bloomfilter
hs-libraries:         HSbloomfilter-2.0.1.2-JJba1usFi2T49LbYQ8hqND
include-dirs:         /usr/lib/ghc-9.2.8/site-local/bloomfilter-2.0.1.2/include
includes:             lookup3.h
depends:
    array-0.5.4.0 base-4.16.4.0 bytestring-0.11.4.0 deepseq-1.4.6.1

haddock-interfaces:   /usr/share/doc/haskell-bloomfilter/html/bloomfilter.haddock
haddock-html:         /usr/share/doc/haskell-bloomfilter/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
